NYCSR — OpenPlans
Author: New York City Streets Renaissance

# The New York City Streets Renaissance

- Home Page
- Join Us

##### Views View Edit ##### Document Actions # NYCSR last modified 2006-09-15 11:18 ## Welcome to the NYC Streets Renaissance Campaign Headquarters ### The goal of the NYCSR is to tranform New York City streets so that they are safer, more productive and more livable. Streets can be places for neighbors to meet New York City is defined by its vibrant and diverse streets and neighborhoods. Unfortunately, our neighborhoods and business districts are buckling under increasing amounts of dangerous car and truck traffic. Children can no longer play on their own blocks , while parents worry about turning cars smashing into baby carriages. Senior citizens are losing their independence, shut up in their homes for fear of crossing the street. And shoppers and investors are being turned away by chaotic, traffic-choked avenues. This is unacceptable. The time is long overdue for our great city to strike a better balance between traffic and the needs of pedestrians. The NYC Streets Renaissance Campaign aims to: Educate New Yorkers about potential transportation policy changes that will improve quality of life across New York City Promote a rebalancing of this public space away from private vehicles and toward community needs Demonstrate the widespread public support for reform on these issues Tap the potential of New Yorkers to re-imagine their own streets Our Initiatives: Official launch with an exhibition/event at the Municipal Arts Society Preparation of a multimedia information packet, including a inclusion letter, a dvd featuring Clarence's work, and a intro booklet Improvements requested for the nycstreets.org homepage Host many events to supplement our exhibition at the MAS. Promote and distribute studies and papers that dispel myths of streets and transit in NYC. Help neighborhood leaders in the fight for long overdue, common sense improvements to their neighborhood streets To get involved, add your ideas for making New York City a better place to live and work to our Taking it Citywide Neighborhoods page, or visit us at http://www.nycsr.org/involved.php old landing page Together, we can re-imagine the streets of New York City.